check_cov — skchange

Skip to main content
`Ctrl`+`K`

# check_cov

check_cov(cov: _SupportsArray[dtype[Any]] | _NestedSequence[_SupportsArray[dtype[Any]]] | bool | int | float | complex | str | bytes | _NestedSequence[bool | int | float | complex | str | bytes] | Number, X: ndarray) → ndarray

  Check if the fixed covariance matrix parameter is valid.

  Parameters:
    covnp.ndarray

      Fixed covariance matrix for the cost calculation.

    Xnp.ndarray

      2d input data.

  Returns:
    covnp.ndarray

      Fixed covariance matrix for the cost calculation.